@@ -31,7 +31,7 @@
 *      width: picture width
 *      height: picture height
 */
-int 
+void 
 yuv420_to_yuyv (BYTE *framebuffer, BYTE *tmpbuffer, int width, int height);
 
 /*convert yvu 420 planar (yv12) to yuv 422 (yuyv)
@@ -41,7 +41,52 @@ yuv420_to_yuyv (BYTE *framebuffer, BYTE *tmpbuffer, int width, int height);
 *      width: picture width
 *      height: picture height
 */
-int yvu420_to_yuyv (BYTE *framebuffer, BYTE *tmpbuffer, int width, int height);
+void yvu420_to_yuyv (BYTE *framebuffer, BYTE *tmpbuffer, int width, int height);
+
+/*convert yuv 420 planar (uv interleaved) (nv12) to yuv 422
+* args: 
+*      framebuffer: pointer to frame buffer (yuyv)
+*      tmpbuffer: pointer to temp buffer containing yuv420 (nv12) planar data frame
+*      width: picture width
+*      height: picture height
+*/
+void nv12_to_yuyv (BYTE *framebuffer, BYTE *tmpbuffer, int width, int height);
+
+/*convert yuv 420 planar (vu interleaved) (nv21) to yuv 422
+* args: 
+*      framebuffer: pointer to frame buffer (yuyv)
+*      tmpbuffer: pointer to temp buffer containing yuv420 (nv21) planar data frame
+*      width: picture width
+*      height: picture height
+*/
+void nv21_to_yuyv (BYTE *framebuffer, BYTE *tmpbuffer, int width, int height);
+
+/*convert yuv 422 planar (uv interleaved) (nv16) to yuv 422
+* args: 
+*      framebuffer: pointer to frame buffer (yuyv)
+*      tmpbuffer: pointer to temp buffer containing yuv422 (nv16) planar data frame
+*      width: picture width
+*      height: picture height
+*/
+void nv16_to_yuyv (BYTE *framebuffer, BYTE *tmpbuffer, int width, int height);
+
+/*convert yuv 422 planar (vu interleaved) (nv61) to yuv 422
+* args: 
+*      framebuffer: pointer to frame buffer (yuyv)
+*      tmpbuffer: pointer to temp buffer containing yuv422 (nv61) planar data frame
+*      width: picture width
+*      height: picture height
+*/
+void nv61_to_yuyv (BYTE *framebuffer, BYTE *tmpbuffer, int width, int height);
+
+/*convert y16 (grey) to yuyv (packed)
+* args: 
+*      framebuffer: pointer to frame buffer (yuyv)
+*      tmpbuffer: pointer to temp buffer containing y16 (grey) data frame
+*      width: picture width
+*      height: picture height
+*/
+void y16_to_yuyv (BYTE *framebuffer, BYTE *tmpbuffer, int width, int height);
 
 /*convert yyuv to yuyv
 * args: 
@@ -71,6 +116,57 @@ void uyvy_to_yuyv (BYTE *framebuffer, BYTE *tmpbuffer, int width, int height);
 */
 void yvyu_to_yuyv (BYTE *framebuffer, BYTE *tmpbuffer, int width, int height);
 
+/*convert yuv 411 packed (y41p) to yuv 422
+* args: 
+*      framebuffer: pointer to frame buffer (yuyv)
+*      tmpbuffer: pointer to temp buffer containing y41p data frame
+*      width: picture width
+*      height: picture height
+*/
+void y41p_to_yuyv (BYTE *framebuffer, BYTE *tmpbuffer, int width, int height);
+
+/*convert yuv mono (grey) to yuv 422
+* args: 
+*      framebuffer: pointer to frame buffer (yuyv)
+*      tmpbuffer: pointer to temp buffer containing grey (y only) data frame
+*      width: picture width
+*      height: picture height
+*/
+void grey_to_yuyv (BYTE *framebuffer, BYTE *tmpbuffer, int width, int height);
+
+/*convert SPCA501 (s501) to yuv 422
+* s501  |Y0..width..Y0|U..width/2..U|Y1..width..Y1|V..width/2..V|
+* signed values (-128;+127) must be converted to unsigned (0; 255)
+* args: 
+*      framebuffer: pointer to frame buffer (yuyv)
+*      tmpbuffer: pointer to temp buffer containing s501 data frame
+*      width: picture width
+*      height: picture height
+*/
+void s501_to_yuyv(BYTE *framebuffer, BYTE *tmpbuffer, int width, int height);
+
+/*convert SPCA505 (s505) to yuv 422
+* s505  |Y0..width..Y0|Y1..width..Y1|U..width/2..U|V..width/2..V|
+* signed values (-128;+127) must be converted to unsigned (0; 255)
+* args: 
+*      framebuffer: pointer to frame buffer (yuyv)
+*      tmpbuffer: pointer to temp buffer containing s501 data frame
+*      width: picture width
+*      height: picture height
+*/
+void s505_to_yuyv(BYTE *framebuffer, BYTE *tmpbuffer, int width, int height);
+
+/*convert SPCA508 (s508) to yuv 422
+* s508  |Y0..width..Y0|U..width/2..U|V..width/2..V|Y1..width..Y1|
+* signed values (-128;+127) must be converted to unsigned (0; 255)
+* args: 
+*      framebuffer: pointer to frame buffer (yuyv)
+*      tmpbuffer: pointer to temp buffer containing s501 data frame
+*      width: picture width
+*      height: picture height
+*/
+void s508_to_yuyv(BYTE *framebuffer, BYTE *tmpbuffer, int width, int height);
+
 /*convert yuyv to rgb24
 * args: 
 *      pyuv: pointer to buffer containing yuv data (yuyv)
@@ -93,6 +189,11 @@ yuyv2rgb (BYTE *pyuv, BYTE *prgb, int width, int height);
 void 
 yuyv2bgr (BYTE *pyuv, BYTE *pbgr, int width, int height);
 
+/* used for rgb video (fourcc="RGB ")
+*  lines are in correct order
+*/
+void 
+yuyv2bgr1 (BYTE *pyuv, BYTE *pbgr, int width, int height);
 
 /*convert bayer raw data to rgb24
 * args: 
