@@ -46,14 +46,17 @@ static void alloc_videoBuff(struct ALL_DATA *all_data)
 	struct GLOBAL *global = all_data->global;
 	int i = 0;
 	int framesize = global->height*global->width*2; /*yuyv (maximum size)*/
+	if((global->fps > 0) && (global->fps_num > 0))
+	    global->video_buff_size = (global->fps * 3) / (global->fps_num * 2); /* 1,5 seconds of video in buffer*/
+	if (global->video_buff_size < 2) global->video_buff_size = 2; /*keep at least two frames*/
 	
 	/*alloc video ring buffer*/
 	g_mutex_lock(global->mutex);
 		if (global->videoBuff == NULL)
 		{
 			/*alloc video frames to videoBuff*/
-			global->videoBuff = g_new0(VidBuff,VIDBUFF_SIZE);
-			for(i=0;i<VIDBUFF_SIZE;i++)
+			global->videoBuff = g_new0(VidBuff, global->video_buff_size);
+			for(i=0;i<global->video_buff_size;i++)
 			{
 				global->videoBuff[i].frame = g_new0(BYTE,framesize);
 			}
@@ -61,7 +64,7 @@ static void alloc_videoBuff(struct ALL_DATA *all_data)
 		else
 		{
 			/*free video frames to videoBuff*/
-			for(i=0;i<VIDBUFF_SIZE;i++)
+			for(i=0;i<global->video_buff_size;i++)
 			{
 				if(global->videoBuff[i].frame) g_free(global->videoBuff[i].frame);
 				global->videoBuff[i].frame = NULL;
@@ -69,8 +72,8 @@ static void alloc_videoBuff(struct ALL_DATA *all_data)
 			g_free(global->videoBuff);
 			
 			/*alloc video frames to videoBuff*/
-			global->videoBuff = g_new0(VidBuff,VIDBUFF_SIZE);
-			for(i=0;i<VIDBUFF_SIZE;i++)
+			global->videoBuff = g_new0(VidBuff,global->video_buff_size);
+			for(i=0;i<global->video_buff_size;i++)
 			{
 				global->videoBuff[i].frame = g_new0(BYTE,framesize);
 			}
@@ -151,10 +154,15 @@ static int initVideoFile(struct ALL_DATA *all_data, void * lavc_aud_data)
 					{
 						g_printerr("error opening portaudio\n");
 						global->Sound_enable=0;
-						gdk_threads_enter();
-						gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gwidget->SndEnable),0);
-						gdk_flush();
-						gdk_threads_leave();
+						if(!(global->no_display))
+                        {
+						    gdk_threads_enter();
+						    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gwidget->SndEnable),0);
+						    gdk_flush();
+						    gdk_threads_leave();
+						}
+						else
+                            capture_vid(NULL, all_data);
 					} 
 				}
 			}
@@ -196,11 +204,16 @@ static int initVideoFile(struct ALL_DATA *all_data, void * lavc_aud_data)
 				{
 					g_printerr("error opening portaudio\n");
 					global->Sound_enable=0;
-					/*will this work with the checkbox disabled?*/
-					gdk_threads_enter();
-					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gwidget->SndEnable),0);
-					gdk_flush();
-					gdk_threads_leave();
+					if(!(global->no_display))
+                    {
+					    /*will this work with the checkbox disabled?*/
+					    gdk_threads_enter();
+					    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gwidget->SndEnable),0);
+					    gdk_flush();
+					    gdk_threads_leave();
+					}
+					else
+					    capture_vid(NULL, all_data);
 				}
 			}
 			break;
@@ -295,7 +308,7 @@ static void closeVideoFile(struct ALL_DATA *all_data)
 		if (global->videoBuff != NULL)
 		{
 			/*free video frames to videoBuff*/
-			for(i=0;i<VIDBUFF_SIZE;i++)
+			for(i=0;i<global->video_buff_size;i++)
 			{
 				g_free(global->videoBuff[i].frame);
 				global->videoBuff[i].frame = NULL;
@@ -364,10 +377,15 @@ static int write_video_frame (struct ALL_DATA *all_data,
 							g_printerr("Thread create failed: %s!!\n", err1->message );
 							g_error_free ( err1 ) ;
 							printf("stoping video capture\n");
-							gdk_threads_enter();
-							gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(gwidget->CapVidButt), FALSE);
-							gdk_flush();
-							gdk_threads_leave();
+							if(!(global->no_display))
+                            {
+							    gdk_threads_enter();
+							    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(gwidget->CapVidButt), FALSE);
+							    gdk_flush();
+							    gdk_threads_leave();
+							}
+							else
+							    capture_vid(NULL, all_data);
 						}
 						g_printf("AVI file size limit reached - restarted capture on new file\n");
 					}
@@ -428,10 +446,15 @@ static int write_audio_frame (struct ALL_DATA *all_data, void *lavc_adata, AudBu
 							g_printerr("Thread create failed: %s!!\n", err1->message );
 							g_error_free ( err1 ) ;
 							printf("stoping video capture\n");
-							gdk_threads_enter();
-							gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(gwidget->CapVidButt), FALSE);
-							gdk_flush();
-							gdk_threads_leave();
+							if(!(global->no_display))
+                            {
+							    gdk_threads_enter();
+							    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(gwidget->CapVidButt), FALSE);
+							    gdk_flush();
+							    gdk_threads_leave();
+							}
+							else
+							    capture_vid(NULL, all_data);
 						}
 					
 						//split_avi(all_data);/*blocking call*/
@@ -511,7 +534,7 @@ static int sync_audio_frame(struct ALL_DATA *all_data, AudBuff *proc_buff)
 	return (0);
 }
 
-static int buff_scheduler(int w_ind, int r_ind)
+static int buff_scheduler(int w_ind, int r_ind, int buff_size)
 {
 	int diff_ind = 0;
 	int sched_sleep = 0;
@@ -519,7 +542,7 @@ static int buff_scheduler(int w_ind, int r_ind)
 	if(w_ind >= r_ind)
 		diff_ind = w_ind - r_ind;
 	else
-		diff_ind = (VIDBUFF_SIZE - r_ind) + w_ind;
+		diff_ind = (buff_size - r_ind) + w_ind;
 
 	if(diff_ind <= 15) sched_sleep = 0; /* full throttle (must wait for audio at least 10 frames) */
 	else if (diff_ind <= 20) sched_sleep = (diff_ind-15) * 2; /* <= 10  ms ~1 frame @ 90  fps */
@@ -614,7 +637,16 @@ static gboolean process_video(struct ALL_DATA *all_data,
 {
 	struct GLOBAL *global = all_data->global;
 	struct vdIn *videoIn = all_data->videoIn;
+	struct paRecordData *pdata = all_data->pdata;
+	int64_t max_drift = 0, audio_drift = 0;
 	
+	if (global->Sound_enable) {
+		g_mutex_lock(pdata->mutex);
+			audio_drift = pdata->ts_drift;
+		g_mutex_unlock(pdata->mutex);
+		max_drift = 1000000000 / global->fps;	/* one frame */
+	}
+
 	g_mutex_lock(videoIn->mutex);
 		gboolean capVid = videoIn->capVid;
 	g_mutex_unlock(videoIn->mutex);
@@ -635,11 +667,60 @@ static gboolean process_video(struct ALL_DATA *all_data,
 			/*signals an empty slot in the video buffer*/
 			g_cond_broadcast(global->IO_cond);
 				
-			NEXT_IND(global->r_ind,VIDBUFF_SIZE);
+			NEXT_IND(global->r_ind,global->video_buff_size);
+			audio_drift -= global->av_drift;
 		g_mutex_unlock(global->mutex);
 
+		/* fprintf(stderr, "audio drift = %lli ms\n", audio_drift / 1000000); */
 		/*process video Frame*/
-		write_video_frame(all_data, (void *) jpeg_struct, (void *) lavc_data, proc_buff);
+		if (audio_drift > max_drift)
+		{
+			/* audio delayed */
+			g_printf("audio drift: dropping/shifting frame\n");
+			g_mutex_lock(global->mutex);
+				global->av_drift += max_drift;
+			g_mutex_unlock(global->mutex);
+
+			switch (global->VidFormat)
+			{
+				case AVI_FORMAT:
+					/* drop frame */
+					break;
+
+				case MKV_FORMAT:
+					write_video_frame(all_data, (void *) jpeg_struct, (void *) lavc_data, proc_buff);
+					break;
+
+				default:
+					break;
+			}
+		}
+		else if (audio_drift < -1 * max_drift)
+		{
+			/* audio too fast */
+			g_printf("audio drift: duplicating/shifting frame\n");
+			g_mutex_lock(global->mutex);
+				global->av_drift -= max_drift;
+			g_mutex_unlock(global->mutex);
+
+			switch (global->VidFormat)
+			{
+				case AVI_FORMAT:
+					/* write frame twice */
+					write_video_frame(all_data, (void *) jpeg_struct, (void *) lavc_data, proc_buff);
+					write_video_frame(all_data, (void *) jpeg_struct, (void *) lavc_data, proc_buff);
+					break;
+
+				case MKV_FORMAT:
+					write_video_frame(all_data, (void *) jpeg_struct, (void *) lavc_data, proc_buff);
+					break;
+
+				default:
+					break;
+			}
+		}
+		else
+			write_video_frame(all_data, (void *) jpeg_struct, (void *) lavc_data, proc_buff);
 	}
 	else
 	{
@@ -665,7 +746,7 @@ static void store_at_index(void *data)
 	struct GLOBAL *global = all_data->global;
 	struct vdIn *videoIn = all_data->videoIn;
 
-	global->videoBuff[global->w_ind].time_stamp = global->v_ts;
+	global->videoBuff[global->w_ind].time_stamp = global->v_ts - global->av_drift;
 	
 	/*store frame at index*/
 	if ((global->VidCodec == CODEC_MJPEG) && (global->Frame_Flags==0) &&
@@ -717,8 +798,8 @@ int store_video_frame(void *data)
 	if (!global->videoBuff[global->w_ind].used)
 	{
 		store_at_index(data);
-		producer_sleep = buff_scheduler(global->w_ind, global->r_ind);
-		NEXT_IND(global->w_ind, VIDBUFF_SIZE);
+		producer_sleep = buff_scheduler(global->w_ind, global->r_ind, global->video_buff_size);
+		NEXT_IND(global->w_ind, global->video_buff_size);
 	}
 	else
 	{
@@ -735,7 +816,8 @@ int store_video_frame(void *data)
 			if (!global->videoBuff[global->w_ind].used)
 			{
 				store_at_index(data);
-				NEXT_IND(global->w_ind, VIDBUFF_SIZE);
+                producer_sleep = buff_scheduler(global->w_ind, global->r_ind, global->video_buff_size);
+				NEXT_IND(global->w_ind, global->video_buff_size);
 			}
 			else ret = -2;/*drop frame*/
 			
@@ -787,19 +869,21 @@ void *IO_loop(void *data)
 	if(initVideoFile(all_data, (void *) &(lavc_audio_data))<0)
 	{
 		g_printerr("Cap Video failed\n");
+		if(!(global->no_display))
+        {
+		    gdk_threads_enter();
+		    /*disable signals for video capture callback*/
+		    g_signal_handlers_block_by_func(GTK_TOGGLE_BUTTON(gwidget->CapVidButt), G_CALLBACK (capture_vid), all_data);
+		    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(gwidget->CapVidButt), FALSE);
+		    gtk_button_set_label(GTK_BUTTON(gwidget->CapVidButt),_("Cap. Video"));
+		    /*enable signals for video capture callback*/
+		    g_signal_handlers_unblock_by_func(GTK_TOGGLE_BUTTON(gwidget->CapVidButt), G_CALLBACK (capture_vid), all_data);
+		    gdk_flush();
+		    gdk_threads_leave();
 		
-		gdk_threads_enter();
-		/*disable signals for video capture callback*/
-		g_signal_handlers_block_by_func(GTK_TOGGLE_BUTTON(gwidget->CapVidButt), G_CALLBACK (capture_vid), all_data);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(gwidget->CapVidButt), FALSE);
-		gtk_button_set_label(GTK_BUTTON(gwidget->CapVidButt),_("Cap. Video"));
-		/*enable signals for video capture callback*/
-		g_signal_handlers_unblock_by_func(GTK_TOGGLE_BUTTON(gwidget->CapVidButt), G_CALLBACK (capture_vid), all_data);
-		gdk_flush();
-		gdk_threads_leave();
-		
-		/*enabling sound and video compression controls*/
-		set_sensitive_vid_contrls(TRUE, global->Sound_enable, gwidget);
+		    /*enabling sound and video compression controls*/
+		    set_sensitive_vid_contrls(TRUE, global->Sound_enable, gwidget);
+		}
 		
 		finished = TRUE;
 		failed = TRUE;
@@ -816,6 +900,8 @@ void *IO_loop(void *data)
 			aud_eff=init_audio_effects ();
 			aud_proc_buff = g_new0(AudBuff, 1);
 			aud_proc_buff->frame = g_new0(SAMPLE, pdata->aud_numSamples);
+			global->av_drift = 0;
+			pdata->ts_drift = 0;
 		}
 	}
 	
@@ -835,7 +921,7 @@ void *IO_loop(void *data)
 					if(global->w_ind >= global->r_ind)
 						diff_ind = global->w_ind - global->r_ind;
 					else
-						diff_ind = (VIDBUFF_SIZE - global->r_ind) + global->w_ind;
+						diff_ind = (global->video_buff_size - global->r_ind) + global->w_ind;
 			
 					if( (pdata->audio_buff[pdata->r_ind].used && global->videoBuff[global->r_ind].used) &&
 						(pdata->audio_buff[pdata->r_ind].time_stamp < global->videoBuff[global->r_ind].time_stamp))
@@ -909,14 +995,12 @@ void *IO_loop(void *data)
 	
 	if(lavc_data != NULL)
 	{
-		int nf = clean_lavc(&lavc_data);
-		if(global->debug) g_printf(" total frames encoded: %d\n", nf);
+		clean_lavc(&lavc_data);
 		lavc_data = NULL;
 	}
 	if(lavc_audio_data != NULL)
 	{
-		int nf = clean_lavc_audio(&lavc_audio_data);
-		if(global->debug) g_printf(" total audio frames encoded: %d\n", nf);
+		clean_lavc_audio(&lavc_audio_data);
 		lavc_audio_data = NULL;
 	}
 	if(jpg_data != NULL) g_free(jpg_data);
