@@ -108,6 +108,8 @@ writeConf(struct GLOBAL *global, char *videodevice)
 		//g_fprintf(fp,"Tilt_Step=%i\n",global->TiltStep);
 		g_fprintf(fp,"# video filters: 0 -none 1- flip 2- upturn 4- negate 8- mono (add the ones you want)\n");
 		g_fprintf(fp,"frame_flags=%i\n",global->Frame_Flags);
+		g_fprintf(fp,"#on screen display flags (VU meter)\n");
+		g_fprintf(fp,"osd_flags=%i\n",global->osdFlags);
 		g_fprintf(fp,"# Auto Image naming (filename-n.ext)\n");
 		g_fprintf(fp,"image_inc=%d\n",global->image_inc);
 		g_fprintf(fp,"# Image capture Full Path\n");
@@ -480,6 +482,10 @@ readConf(struct GLOBAL *global)
 						{
 							global->Frame_Flags = scanner->value.v_int;
 						}
+						else if (g_strcmp0(name,"osd_flags")==0) 
+						{
+							global->osdFlags = scanner->value.v_int;
+						}
 						else if (g_strcmp0(name,"image_inc")==0) 
 						{
 							global->image_inc = (DWORD) scanner->value.v_int;
@@ -730,6 +736,7 @@ readOpts(int argc,char *argv[], struct GLOBAL *global)
 		{ "device", 'd', 0, G_OPTION_ARG_STRING, &device, N_("Video Device to use [default: /dev/video0]"), "VIDEO_DEVICE" },
 		{ "add_ctrls", 'a', 0, G_OPTION_ARG_NONE, &global->add_ctrls, N_("Exit after adding UVC extension controls (needs root/sudo)"), NULL},
 		{ "control_only", 'o', 0, G_OPTION_ARG_NONE, &global->control_only, N_("Don't stream video (image controls only)"), NULL},
+        { "no_display", 0,0, G_OPTION_ARG_NONE, &global->no_display, N_("Don't display a GUI"), NULL},
 		{ "capture_method", 'r', 0, G_OPTION_ARG_INT, &cap_meth, N_("Capture method (1-mmap (default)  2-read)"), "[1 | 2]"},
 		{ "config", 'g', 0, G_OPTION_ARG_STRING, &config, N_("Configuration file"), "FILENAME" },
 		{ "hwd_acel", 'w', 0, G_OPTION_ARG_INT, &hwaccel, N_("Hardware accelaration (enable(1) | disable(0))"), "[1 | 0]" },
